# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='model.proto',
  package='kclvm.doc.model',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bmodel.proto\x12\x0fkclvm.doc.model\"\x83\x01\n\tModuleDoc\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rrelative_path\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12+\n\x07schemas\x18\x04 \x03(\x0b\x32\x1a.kclvm.doc.model.SchemaDoc\x12\x17\n\x0fsource_code_url\x18\x05 \x01(\t\"\x9d\x01\n\tSchemaDoc\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x64oc\x18\x02 \x01(\t\x12\x37\n\nattributes\x18\x03 \x03(\x0b\x32#.kclvm.doc.model.SchemaAttributeDoc\x12\x10\n\x08\x65xamples\x18\x04 \x01(\t\x12*\n\x0b\x62\x61se_schema\x18\x05 \x01(\x0b\x32\x15.kclvm.doc.model.Type\"\x80\x01\n\x12SchemaAttributeDoc\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x64oc\x18\x02 \x01(\t\x12#\n\x04type\x18\x04 \x01(\x0b\x32\x15.kclvm.doc.model.Type\x12\x13\n\x0bis_optional\x18\x05 \x01(\x08\x12\x15\n\rdefault_value\x18\x06 \x01(\t\"\x9c\x06\n\x04Type\x12\x10\n\x08type_str\x18\x01 \x01(\t\x12\x39\n\rtype_category\x18\x02 \x01(\x0e\x32\".kclvm.doc.model.Type.TypeCategory\x12\x33\n\nunion_type\x18\x03 \x01(\x0b\x32\x1a.kclvm.doc.model.UnionTypeH\x00\x88\x01\x01\x12\x31\n\tlist_type\x18\x04 \x01(\x0b\x32\x19.kclvm.doc.model.ListTypeH\x01\x88\x01\x01\x12\x31\n\tdict_type\x18\x05 \x01(\x0b\x32\x19.kclvm.doc.model.DictTypeH\x02\x88\x01\x01\x12\x35\n\x0bschema_type\x18\x06 \x01(\x0b\x32\x1b.kclvm.doc.model.SchemaTypeH\x03\x88\x01\x01\x12<\n\x0c\x62uiltin_type\x18\x07 \x01(\x0e\x32!.kclvm.doc.model.Type.BuiltinTypeH\x04\x88\x01\x01\x12/\n\x08lit_type\x18\x08 \x01(\x0b\x32\x18.kclvm.doc.model.LitTypeH\x05\x88\x01\x01\x12@\n\x0enamed_constant\x18\t \x01(\x0e\x32#.kclvm.doc.model.Type.NamedConstantH\x06\x88\x01\x01\"\x83\x01\n\x0cTypeCategory\x12\t\n\x05UNION\x10\x00\x12\x08\n\x04LIST\x10\x01\x12\x08\n\x04\x44ICT\x10\x02\x12\n\n\x06SCHEMA\x10\x03\x12\x0b\n\x07\x42UILTIN\x10\x04\x12\x07\n\x03LIT\x10\x05\x12\x12\n\x0eNAMED_CONSTANT\x10\x06\x12\x07\n\x03\x41NY\x10\x07\x12\x15\n\x11NUMBER_MULTIPLIER\x10\x08\"7\n\x0b\x42uiltinType\x12\x07\n\x03INT\x10\x00\x12\t\n\x05\x46LOAT\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\"\x19\n\rNamedConstant\x12\x08\n\x04NONE\x10\x00\x42\r\n\x0b_union_typeB\x0c\n\n_list_typeB\x0c\n\n_dict_typeB\x0e\n\x0c_schema_typeB\x0f\n\r_builtin_typeB\x0b\n\t_lit_typeB\x11\n\x0f_named_constant\"1\n\tUnionType\x12$\n\x05types\x18\x01 \x03(\x0b\x32\x15.kclvm.doc.model.Type\"4\n\x08ListType\x12(\n\titem_type\x18\x01 \x01(\x0b\x32\x15.kclvm.doc.model.Type\"^\n\x08\x44ictType\x12\'\n\x08key_type\x18\x01 \x01(\x0b\x32\x15.kclvm.doc.model.Type\x12)\n\nvalue_type\x18\x02 \x01(\x0b\x32\x15.kclvm.doc.model.Type\"1\n\nSchemaType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rrelative_path\x18\x02 \x01(\t\"\x9d\x01\n\x07LitType\x12\x17\n\nstring_lit\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07int_lit\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x16\n\tfloat_lit\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x15\n\x08\x62ool_lit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\r\n\x0b_string_litB\n\n\x08_int_litB\x0c\n\n_float_litB\x0b\n\t_bool_litb\x06proto3'
)



_TYPE_TYPECATEGORY = _descriptor.EnumDescriptor(
  name='TypeCategory',
  full_name='kclvm.doc.model.Type.TypeCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DICT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEMA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUILTIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAMED_CONSTANT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER_MULTIPLIER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=931,
  serialized_end=1062,
)
_sym_db.RegisterEnumDescriptor(_TYPE_TYPECATEGORY)

_TYPE_BUILTINTYPE = _descriptor.EnumDescriptor(
  name='BuiltinType',
  full_name='kclvm.doc.model.Type.BuiltinType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1064,
  serialized_end=1119,
)
_sym_db.RegisterEnumDescriptor(_TYPE_BUILTINTYPE)

_TYPE_NAMEDCONSTANT = _descriptor.EnumDescriptor(
  name='NamedConstant',
  full_name='kclvm.doc.model.Type.NamedConstant',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1121,
  serialized_end=1146,
)
_sym_db.RegisterEnumDescriptor(_TYPE_NAMEDCONSTANT)


_MODULEDOC = _descriptor.Descriptor(
  name='ModuleDoc',
  full_name='kclvm.doc.model.ModuleDoc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kclvm.doc.model.ModuleDoc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_path', full_name='kclvm.doc.model.ModuleDoc.relative_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='kclvm.doc.model.ModuleDoc.doc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schemas', full_name='kclvm.doc.model.ModuleDoc.schemas', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='kclvm.doc.model.ModuleDoc.source_code_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=164,
)


_SCHEMADOC = _descriptor.Descriptor(
  name='SchemaDoc',
  full_name='kclvm.doc.model.SchemaDoc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kclvm.doc.model.SchemaDoc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='kclvm.doc.model.SchemaDoc.doc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='kclvm.doc.model.SchemaDoc.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='examples', full_name='kclvm.doc.model.SchemaDoc.examples', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_schema', full_name='kclvm.doc.model.SchemaDoc.base_schema', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=324,
)


_SCHEMAATTRIBUTEDOC = _descriptor.Descriptor(
  name='SchemaAttributeDoc',
  full_name='kclvm.doc.model.SchemaAttributeDoc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kclvm.doc.model.SchemaAttributeDoc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='kclvm.doc.model.SchemaAttributeDoc.doc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='kclvm.doc.model.SchemaAttributeDoc.type', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_optional', full_name='kclvm.doc.model.SchemaAttributeDoc.is_optional', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='kclvm.doc.model.SchemaAttributeDoc.default_value', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=455,
)


_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='kclvm.doc.model.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_str', full_name='kclvm.doc.model.Type.type_str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_category', full_name='kclvm.doc.model.Type.type_category', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='union_type', full_name='kclvm.doc.model.Type.union_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_type', full_name='kclvm.doc.model.Type.list_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dict_type', full_name='kclvm.doc.model.Type.dict_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_type', full_name='kclvm.doc.model.Type.schema_type', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='builtin_type', full_name='kclvm.doc.model.Type.builtin_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lit_type', full_name='kclvm.doc.model.Type.lit_type', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_constant', full_name='kclvm.doc.model.Type.named_constant', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_TYPECATEGORY,
    _TYPE_BUILTINTYPE,
    _TYPE_NAMEDCONSTANT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_union_type', full_name='kclvm.doc.model.Type._union_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_list_type', full_name='kclvm.doc.model.Type._list_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_dict_type', full_name='kclvm.doc.model.Type._dict_type',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_schema_type', full_name='kclvm.doc.model.Type._schema_type',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_builtin_type', full_name='kclvm.doc.model.Type._builtin_type',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lit_type', full_name='kclvm.doc.model.Type._lit_type',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_named_constant', full_name='kclvm.doc.model.Type._named_constant',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=458,
  serialized_end=1254,
)


_UNIONTYPE = _descriptor.Descriptor(
  name='UnionType',
  full_name='kclvm.doc.model.UnionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='kclvm.doc.model.UnionType.types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1305,
)


_LISTTYPE = _descriptor.Descriptor(
  name='ListType',
  full_name='kclvm.doc.model.ListType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_type', full_name='kclvm.doc.model.ListType.item_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1359,
)


_DICTTYPE = _descriptor.Descriptor(
  name='DictType',
  full_name='kclvm.doc.model.DictType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_type', full_name='kclvm.doc.model.DictType.key_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='kclvm.doc.model.DictType.value_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1455,
)


_SCHEMATYPE = _descriptor.Descriptor(
  name='SchemaType',
  full_name='kclvm.doc.model.SchemaType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kclvm.doc.model.SchemaType.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_path', full_name='kclvm.doc.model.SchemaType.relative_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1457,
  serialized_end=1506,
)


_LITTYPE = _descriptor.Descriptor(
  name='LitType',
  full_name='kclvm.doc.model.LitType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_lit', full_name='kclvm.doc.model.LitType.string_lit', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_lit', full_name='kclvm.doc.model.LitType.int_lit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_lit', full_name='kclvm.doc.model.LitType.float_lit', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_lit', full_name='kclvm.doc.model.LitType.bool_lit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_string_lit', full_name='kclvm.doc.model.LitType._string_lit',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_int_lit', full_name='kclvm.doc.model.LitType._int_lit',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_float_lit', full_name='kclvm.doc.model.LitType._float_lit',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_bool_lit', full_name='kclvm.doc.model.LitType._bool_lit',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1509,
  serialized_end=1666,
)

_MODULEDOC.fields_by_name['schemas'].message_type = _SCHEMADOC
_SCHEMADOC.fields_by_name['attributes'].message_type = _SCHEMAATTRIBUTEDOC
_SCHEMADOC.fields_by_name['base_schema'].message_type = _TYPE
_SCHEMAATTRIBUTEDOC.fields_by_name['type'].message_type = _TYPE
_TYPE.fields_by_name['type_category'].enum_type = _TYPE_TYPECATEGORY
_TYPE.fields_by_name['union_type'].message_type = _UNIONTYPE
_TYPE.fields_by_name['list_type'].message_type = _LISTTYPE
_TYPE.fields_by_name['dict_type'].message_type = _DICTTYPE
_TYPE.fields_by_name['schema_type'].message_type = _SCHEMATYPE
_TYPE.fields_by_name['builtin_type'].enum_type = _TYPE_BUILTINTYPE
_TYPE.fields_by_name['lit_type'].message_type = _LITTYPE
_TYPE.fields_by_name['named_constant'].enum_type = _TYPE_NAMEDCONSTANT
_TYPE_TYPECATEGORY.containing_type = _TYPE
_TYPE_BUILTINTYPE.containing_type = _TYPE
_TYPE_NAMEDCONSTANT.containing_type = _TYPE
_TYPE.oneofs_by_name['_union_type'].fields.append(
  _TYPE.fields_by_name['union_type'])
_TYPE.fields_by_name['union_type'].containing_oneof = _TYPE.oneofs_by_name['_union_type']
_TYPE.oneofs_by_name['_list_type'].fields.append(
  _TYPE.fields_by_name['list_type'])
_TYPE.fields_by_name['list_type'].containing_oneof = _TYPE.oneofs_by_name['_list_type']
_TYPE.oneofs_by_name['_dict_type'].fields.append(
  _TYPE.fields_by_name['dict_type'])
_TYPE.fields_by_name['dict_type'].containing_oneof = _TYPE.oneofs_by_name['_dict_type']
_TYPE.oneofs_by_name['_schema_type'].fields.append(
  _TYPE.fields_by_name['schema_type'])
_TYPE.fields_by_name['schema_type'].containing_oneof = _TYPE.oneofs_by_name['_schema_type']
_TYPE.oneofs_by_name['_builtin_type'].fields.append(
  _TYPE.fields_by_name['builtin_type'])
_TYPE.fields_by_name['builtin_type'].containing_oneof = _TYPE.oneofs_by_name['_builtin_type']
_TYPE.oneofs_by_name['_lit_type'].fields.append(
  _TYPE.fields_by_name['lit_type'])
_TYPE.fields_by_name['lit_type'].containing_oneof = _TYPE.oneofs_by_name['_lit_type']
_TYPE.oneofs_by_name['_named_constant'].fields.append(
  _TYPE.fields_by_name['named_constant'])
_TYPE.fields_by_name['named_constant'].containing_oneof = _TYPE.oneofs_by_name['_named_constant']
_UNIONTYPE.fields_by_name['types'].message_type = _TYPE
_LISTTYPE.fields_by_name['item_type'].message_type = _TYPE
_DICTTYPE.fields_by_name['key_type'].message_type = _TYPE
_DICTTYPE.fields_by_name['value_type'].message_type = _TYPE
_LITTYPE.oneofs_by_name['_string_lit'].fields.append(
  _LITTYPE.fields_by_name['string_lit'])
_LITTYPE.fields_by_name['string_lit'].containing_oneof = _LITTYPE.oneofs_by_name['_string_lit']
_LITTYPE.oneofs_by_name['_int_lit'].fields.append(
  _LITTYPE.fields_by_name['int_lit'])
_LITTYPE.fields_by_name['int_lit'].containing_oneof = _LITTYPE.oneofs_by_name['_int_lit']
_LITTYPE.oneofs_by_name['_float_lit'].fields.append(
  _LITTYPE.fields_by_name['float_lit'])
_LITTYPE.fields_by_name['float_lit'].containing_oneof = _LITTYPE.oneofs_by_name['_float_lit']
_LITTYPE.oneofs_by_name['_bool_lit'].fields.append(
  _LITTYPE.fields_by_name['bool_lit'])
_LITTYPE.fields_by_name['bool_lit'].containing_oneof = _LITTYPE.oneofs_by_name['_bool_lit']
DESCRIPTOR.message_types_by_name['ModuleDoc'] = _MODULEDOC
DESCRIPTOR.message_types_by_name['SchemaDoc'] = _SCHEMADOC
DESCRIPTOR.message_types_by_name['SchemaAttributeDoc'] = _SCHEMAATTRIBUTEDOC
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['UnionType'] = _UNIONTYPE
DESCRIPTOR.message_types_by_name['ListType'] = _LISTTYPE
DESCRIPTOR.message_types_by_name['DictType'] = _DICTTYPE
DESCRIPTOR.message_types_by_name['SchemaType'] = _SCHEMATYPE
DESCRIPTOR.message_types_by_name['LitType'] = _LITTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModuleDoc = _reflection.GeneratedProtocolMessageType('ModuleDoc', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDOC,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.ModuleDoc)
  })
_sym_db.RegisterMessage(ModuleDoc)

SchemaDoc = _reflection.GeneratedProtocolMessageType('SchemaDoc', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMADOC,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.SchemaDoc)
  })
_sym_db.RegisterMessage(SchemaDoc)

SchemaAttributeDoc = _reflection.GeneratedProtocolMessageType('SchemaAttributeDoc', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAATTRIBUTEDOC,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.SchemaAttributeDoc)
  })
_sym_db.RegisterMessage(SchemaAttributeDoc)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.Type)
  })
_sym_db.RegisterMessage(Type)

UnionType = _reflection.GeneratedProtocolMessageType('UnionType', (_message.Message,), {
  'DESCRIPTOR' : _UNIONTYPE,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.UnionType)
  })
_sym_db.RegisterMessage(UnionType)

ListType = _reflection.GeneratedProtocolMessageType('ListType', (_message.Message,), {
  'DESCRIPTOR' : _LISTTYPE,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.ListType)
  })
_sym_db.RegisterMessage(ListType)

DictType = _reflection.GeneratedProtocolMessageType('DictType', (_message.Message,), {
  'DESCRIPTOR' : _DICTTYPE,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.DictType)
  })
_sym_db.RegisterMessage(DictType)

SchemaType = _reflection.GeneratedProtocolMessageType('SchemaType', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMATYPE,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.SchemaType)
  })
_sym_db.RegisterMessage(SchemaType)

LitType = _reflection.GeneratedProtocolMessageType('LitType', (_message.Message,), {
  'DESCRIPTOR' : _LITTYPE,
  '__module__' : 'model_pb2'
  # @@protoc_insertion_point(class_scope:kclvm.doc.model.LitType)
  })
_sym_db.RegisterMessage(LitType)


# @@protoc_insertion_point(module_scope)
